@@ -9,7 +9,7 @@ class Logger:
     def get_log(cls):
         if cls.log is None:
             level = os.environ.get("LOGGER_LEVEL", "INFO")
-            cls.log = logging.getLogger("Learning")
+            cls.log = logging.getLogger()
             cls.log.setLevel(level)
             ch = logging.StreamHandler()
             ch.setLevel(level)
